==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/AssumeRoleFluent.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AssumeRoleFluent<A extends AssumeRoleFluent<A>> extends BaseFluent<A>{
  public AssumeRoleFluent() {
  }
  
  public AssumeRoleFluent(AssumeRole instance) {
    this.copyInstance(instance);
  }
  private String externalID;
  private String roleARN;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(AssumeRole instance) {
    instance = (instance != null ? instance : new AssumeRole());
  
    if (instance != null) {
        this.withExternalID(instance.getExternalID());
        this.withRoleARN(instance.getRoleARN());
        this.withExternalID(instance.getExternalID());
        this.withRoleARN(instance.getRoleARN());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getExternalID() {
    return this.externalID;
  }
  
  public A withExternalID(String externalID) {
    this.externalID=externalID; return (A) this;
  }
  
  public boolean hasExternalID() {
    return this.externalID != null;
  }
  
  public String getRoleARN() {
    return this.roleARN;
  }
  
  public A withRoleARN(String roleARN) {
    this.roleARN=roleARN; return (A) this;
  }
  
  public boolean hasRoleARN() {
    return this.roleARN != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AssumeRoleFluent that = (AssumeRoleFluent) o;
    if (!java.util.Objects.equals(externalID, that.externalID)) return false;
  
    if (!java.util.Objects.equals(roleARN, that.roleARN)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(externalID,  roleARN,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (externalID != null) { sb.append("externalID:"); sb.append(externalID + ","); }
    if (roleARN != null) { sb.append("roleARN:"); sb.append(roleARN + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/AssumeRoleFluent.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AssumeRoleFluent<A extends AssumeRoleFluent<A>> extends BaseFluent<A>{
  public AssumeRoleFluent() {
  }
  
  public AssumeRoleFluent(AssumeRole instance) {
    this.copyInstance(instance);
  }
  private String externalID;
  private String roleARN;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(AssumeRole instance) {
    instance = (instance != null ? instance : new AssumeRole());
    if (instance != null) {
          this.withExternalID(instance.getExternalID());
          this.withRoleARN(instance.getRoleARN());
          this.withExternalID(instance.getExternalID());
          this.withRoleARN(instance.getRoleARN());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getExternalID() {
    return this.externalID;
  }
  
  public A withExternalID(String externalID) {
    this.externalID = externalID;
    return (A) this;
  }
  
  public boolean hasExternalID() {
    return this.externalID != null;
  }
  
  public String getRoleARN() {
    return this.roleARN;
  }
  
  public A withRoleARN(String roleARN) {
    this.roleARN = roleARN;
    return (A) this;
  }
  
  public boolean hasRoleARN() {
    return this.roleARN != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AssumeRoleFluent that = (AssumeRoleFluent) o;
    if (!java.util.Objects.equals(externalID, that.externalID)) return false;
    if (!java.util.Objects.equals(roleARN, that.roleARN)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(externalID,  roleARN,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (externalID != null) { sb.append("externalID:"); sb.append(externalID + ","); }
    if (roleARN != null) { sb.append("roleARN:"); sb.append(roleARN + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
